# small multiples

Add a small-multiples viewer to glue, allowing for the easy comparison of different partitions or facets of a dataset.

![Example Image](https://user-images.githubusercontent.com/3639698/191285037-598dc355-d185-4a23-99d8-318429272c4b.png)

